//
//  EHSDKManager.h
//  EweiHelpSDK
//
//  Created by Kiwi on 16/7/4.
//  Copyright © 2016年 infocare. All rights reserved.
//

#import <Foundation/Foundation.h>

@class EHUser, EHTag;



@interface EHSDKManager : NSObject


/*
 SDK 当前登录用户，
 
 - 在调用 @selector(signinWithEHUser:completion:) 成功后生成数据；
 - 在调用 @selector(signoutWithCompletion:) 成功后清空；
 */
@property (readonly) EHUser * _Nonnull currentUser;


// @return current SDK version
+ (NSString*_Nonnull)SDKVersion;


// @return shared instance
+ (EHSDKManager*_Nonnull)defaultManager;



/*
 SDK 注册
 
 @param <NSString*> appkey 请使用PC登录您的客服系统申请
 @param <NSString*> appsecret 请使用PC登录您的客服系统申请
 @param <NSString*> domain 帮助中心地址，如 "help.ewei.com", 默认 https
 
 @return BOOL 是否注册成功
 */
- (BOOL)registerWithAppKey:(NSString*_Nonnull)appKey appSecret:(NSString*_Nonnull)appSecret domain:(NSString*_Nonnull)domain;



/*
 设置是否打印SDK Log
 
 @param <BOOL> loggingEnabled 请使用PC登录您的客服系统申请
 */
- (void)setLoggingEnabled:(BOOL)loggingEnabled;



/*
 登录授权接口
 
 －请在用户成功登录您的 App 时调用此接口；
 －此方法为异步执行，完成时执行 completionBlock；
 
 @param <NSString*> account 账号，用于易维平台唯一识别用户数据，可以传入 email、mobilePhone、externID，必传参数；
 
 email、mobilePhone、externID 这三个字段为全局唯一，可以作为每个用户的唯一标识符；
 易维平台将利用 account 唯一匹配用户，如未匹配到，将以此为参数创建新用户；
 
 E.g.
 NSString * externID = @"ABCD10021";
 [[EHSDKManager defaultManager] signinWithAccount:externID completion:^(BOOL succeeded) {
    // do something after sign in
 }];
 */
- (void)signinWithAccount:(NSString*_Nullable)account completion:(void(^_Nullable) (BOOL succeeded))completionBlock;



/*
 注销当前用户
 
 －请在用户注销时调用此接口；
 －此方法为异步执行，完成时执行 completionBlock；
 */
- (void)signoutWithCompletion:(void(^_Nullable) (BOOL succeeded))completionBlock;



/*
 修改当前登录用户资料
 
 －必须在用户登录成功后才能调用此接口；
 －不必修改的信息全部传 nil；
 －此方法为异步执行，完成时执行 completionBlock；
 */
- (void)modifyCurrentUserWithName:(nullable NSString*)name phone:(nullable NSString*)phone email:(nullable NSString*)email telephone:(nullable NSString*)telephone nickname:(nullable NSString*)nickname signature:(nullable NSString*)signature completion:(void(^_Nullable) (BOOL succeeded))completionBlock;

- (void)startUnitTest;

@end
